spacepy.time.sec2hms — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- time - Time conversion, manipulation and implementation of Ticktock class »

# spacepy.time.sec2hms

`spacepy.time.` `sec2hms`(sec, rounding=True, days=False, dtobj=False)

  Convert seconds of day to hours, minutes, seconds

  Parameters: | sec : float Seconds of day
  Returns: | out : [hours, minutes, seconds] or datetime.timedelta
  Other Parameters:
  | rounding : boolean set for integer seconds days : boolean set to wrap around day (i.e. modulo 86400) dtobj : boolean set to return a timedelta object

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- time - Time conversion, manipulation and implementation of Ticktock class »